package com.usky.agbox.factory;

import com.alibaba.fastjson.JSONObject;
import com.usky.agbox.RemotePatrolAgboxService;
import com.usky.common.core.exception.FeignBadRequestException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.cloud.openfeign.FallbackFactory;
import org.springframework.stereotype.Component;

/**
 * @author han
 * @date 2024/04/02 15:07
 */
@Component
public class RemotePatrolAgboxFallbackFactory implements FallbackFactory<RemotePatrolAgboxService> {
    private static final Logger log = LoggerFactory.getLogger(RemotePatrolAgboxFallbackFactory.class);

    @Override
    public RemotePatrolAgboxService create(Throwable throwable)
    {
        log.error("agbox服务调用失败:{}", throwable.getMessage());
        return new RemotePatrolAgboxService()
        {
            @Override
            public JSONObject getEventCode() {
                throw new FeignBadRequestException(500,"获取事件编码异常"+throwable.getMessage());
            }
            @Override
            public JSONObject getDeviceList() {
                throw new FeignBadRequestException(500,"获取设备列表异常"+throwable.getMessage());
            }
            @Override
            public JSONObject updateHeart(String requestBody) {
                throw new FeignBadRequestException(500,"更新心跳异常"+throwable.getMessage());
            }
            @Override
            public JSONObject addEvent(String requestBody) {
                throw new FeignBadRequestException(500,"添加事件异常"+throwable.getMessage());
            }
            @Override
            public JSONObject getEvent(String requestBody) {
                throw new FeignBadRequestException(500,"获取事件异常"+throwable.getMessage());
            }
        };
    }
}
